##
##  libuuid.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         libuuid
Summary:      Universally Unique Identifiers (UUID) Library
URL:          http://e2fsprogs.sourceforge.net/
Vendor:       Theodore Ts'o
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Libraries
License:      LGPL
Version:      1.47.3
Release:      20250710

#   list of sources
Source0:      http://downloads.sourceforge.net/sourceforge/e2fsprogs/e2fsprogs-%{version}.tar.gz
Patch0:       libuuid.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, autoconf, make
PreReq:       OpenPKG, openpkg >= 20160101

%description
    This is a library for generating DCE 1.1 compliant Universally
    Unique Identifiers (UUID). It is extracted from the Linux e2fsprogs
    package with which it is originally distributed.

%track
    prog libuuid = {
        version   = %{version}
        url       = http://sourceforge.net/projects/e2fsprogs/files/
        regex     = e2fsprogs-(\d+(\.\d+)+)\.tar\.gz
    }

%prep
    %setup -q -n e2fsprogs-%{version}
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    GREP="grep" \
    ./configure \
        --prefix=%{l_prefix} \
        --disable-threads \
        --disable-nls
    ( cd lib/uuid
      %{l_make} %{l_mflags} uuid.h libuuid.a
    ) || exit $?
    ( cd misc
      %{l_make} %{l_mflags} uuidgen
    ) || exit $?

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/include/e2fs/uuid \
        $RPM_BUILD_ROOT%{l_prefix}/lib/e2fs \
        $RPM_BUILD_ROOT%{l_prefix}/lib/pkgconfig \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man3
    %{l_shtool} install -c -s -m 755 \
        misc/uuidgen $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 644 \
        -e 's;@E2FSPROGS_YEAR@;;' \
        -e 's;@E2FSPROGS_MONTH@;;' \
        -e 's;E2fsprogs version @E2FSPROGS_VERSION@;;' \
        misc/uuidgen.1.in $RPM_BUILD_ROOT%{l_prefix}/man/man1/uuidgen.1
    %{l_shtool} install -c -m 644 \
        lib/uuid/uuid.h $RPM_BUILD_ROOT%{l_prefix}/include/e2fs/uuid/
    %{l_shtool} install -c -m 644 \
        lib/uuid/libuuid.a $RPM_BUILD_ROOT%{l_prefix}/lib/e2fs/
    %{l_shtool} install -c -m 644 \
        lib/uuid/uuid.pc $RPM_BUILD_ROOT%{l_prefix}/lib/pkgconfig/libuuid.pc
    for man in lib/uuid/*.3.in; do
        basename=`echo $man | sed -e 's;^.*/\([^/]*\)\.in$;\1;'`
        %{l_shtool} install -c -m 644 \
            -e 's;@E2FSPROGS_YEAR@;;' \
            -e 's;@E2FSPROGS_MONTH@;;' \
            -e 's;E2fsprogs version @E2FSPROGS_VERSION@;;' \
            $man $RPM_BUILD_ROOT%{l_prefix}/man/man3/$basename
    done
    mv  $RPM_BUILD_ROOT%{l_prefix}/man/man3/uuid.3 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man3/uuid-ef2s.3
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

